/* 
 * $Id: DeploymentInfoService.java 3939 2012-07-18 20:13:29Z mitcje $
 * $URL: https://open.jira.com/svn/IKASAN/tags/ikasan-spec-0.9.0-RC3/service/deployment/src/main/java/org/ikasan/spec/deployment/DeploymentInfoService.java $
 *
 * ====================================================================
 * Ikasan Enterprise Integration Platform
 * 
 * Distributed under the Modified BSD License.
 * Copyright notice: The copyright for this software and a full listing 
 * of individual contributors are as shown in the packaged copyright.txt 
 * file. 
 * 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution.
 *
 *  - Neither the name of the ORGANIZATION nor the names of its contributors may
 *    be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE 
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR 
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE 
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * ====================================================================
 */
package org.ikasan.spec.deployment;

/**
 * Contract for managing the information detailing which is the active
 * server currently running an integration module within a highly available 
 * runtime environment.
 * 
 * The client should call the registerActiveServer for the serverName the
 * module is actively servicing messages on.
 * 
 * The registerInactiveServer records the fact the module is deployed to 
 * that server, but not actively servicing messages.
 * 
 * UnregisterServer removes the recorded entry for this server completely.
 * 
 * @author Ikasan Development Team
 */
public interface DeploymentInfoService
{
    /**
     * Register this as the active server for the deployed module.
     * This will change any existing active entries to inactive and make
     * this server the active server for a module.
     * @param serverName
     */
    public void registerActiveServer(String serverName);

    /**
     * Register this as an inactive server for the deployed module
     * @param serverName
     */
    public void registerInactiveServer(String serverName);
    
    /**
     * Unregister this server for a module
     * @param serverName
     */
    public void unregisterServer(String serverName);
}
